The XShooter Calibration Data can be [downloaded from here](https://www.dropbox.com/sh/mny31n26c16znur/AABb0pwIa7vedduYLeQpfkh2a?dl=0) and the [demo data-suite from here](https://www.dropbox.com/sh/yf3xvmvqj0i461a/AAB2F5nxxsz8CHvvkfMFyeKCa?dl=0).

To download both data-sets to the default location `soxspipe` expects to find them run the following:

```bash
mkdir ~/xshooter-pipeline-data
cd ~/xshooter-pipeline-data
wget -O xshooter-pipeline-data.zip https://www.dropbox.com/sh/rxefq6598cdxngg/AABs0hVao9XmFMSj5BV2L7Rea?dl=1
unzip xshooter-pipeline-data.zip
rm xshooter-pipeline-data.zip
```
